Learn R Programming

sensibo.sky (version 1.0.0)

sensibo.pod.info: Gets additional info of a specific air conditioner (pod) of the authenticated user.

Description

Gets additional info of a specific air conditioner (pod) of the authenticated user.

Usage

sensibo.pod.info(pod, key = getOption("sensibo.key"))

Arguments

pod

(character) Pod unique id.

key

(character) API key from https://home.sensibo.com/me/api.

Value

A list of the available details for the given pod or an empty list if the pod doesn't exist.

Examples

Run this code
# NOT RUN {
# Assuming that a valid Sensibo Sky API Key was created on https://home.sensibo.com/me/api
# and added to a 'sensibo.sky' global option.
#
# options("sensibo.key" = <Your Sensibo API Key>)
 
## Getting the list of pods available to the user
pods.id <- sensibo.pods()

## Getting the details for the first pod
pod.details <- sensibo.pod.info(pods.id[1])

# }

Run the code above in your browser using DataLab