Learn R Programming

sensibo.sky (version 1.0.0)

sensibo.pod.states: Get the specified air conditioner (pod) current and previous states.

Description

Get the specified air conditioner (pod) current and previous states.

Usage

sensibo.pod.states(pod, n = 10, key = getOption("sensibo.key"))

Arguments

pod

(character) Pod unique id.

n

(integer) The number of states to get (max 20); n=1 will get only the current state.

key

(character) API key from https://home.sensibo.com/me/api.

Value

A list with the requested states, starting from the current one.

Examples

Run this code
# NOT RUN {
# Assuming that a valid Sensibo Sky API Key was created on https://home.sensibo.com/me/api
# and added to a 'sensibo.sky' global option.
#
# options("sensibo.key" = <Your Sensibo API Key>)
 
## Getting the list of pods available to the user
pods.id <- sensibo.pods()

## Getting the current state of the first pod
## Even if we're asking for the current state only, a list is returned anyway
pod.current <- sensibo.pod.states(pods.id[1], n = 1) 
# }

Run the code above in your browser using DataLab