# NOT RUN {
# Assuming that a valid Sensibo Sky API Key was created on https://home.sensibo.com/me/api
# and added to a 'sensibo.sky' global option.
#
# options("sensibo.key" = <Your Sensibo API Key>)
## Getting the list of pods available to the user
pods.id <- sensibo.pods()
## Get the climate react settings for the first pod
pod.smartsettings <- sensibo.pod.smartmode(pods.id[1])
# }
Run the code above in your browser using DataLab