# NOT RUN {
# Assuming that a valid Sensibo Sky API Key was created on https://home.sensibo.com/me/api
# and added to a 'sensibo.sky' global option.
#
# options("sensibo.key" = <Your Sensibo API Key>)
## Getting the list of pods available to the user
pods.id <- sensibo.pods()
## Getting the current state of the first pod
## Even if we're asking for the current state only, a list is returned anyway
pod.current <- sensibo.pod.states(pods.id[1], n = 1)
# }
Run the code above in your browser using DataLab